@@ -188,12 +188,8 @@ def django_instance_to_redis_params(
         create_redis_model_from_django_model
 ):
     redis_params = {}
-    exclude_fields = [
-        'ManyToOneRel',
-    ]
     for i, django_field in enumerate(django_instance.__class__._meta.get_fields()):
-        if django_field.__class__.__name__ not in exclude_fields:
-            print(django_field.__class__.__name__)
+        if not django_field.__class__.__name__.endswith('Rel'):
             redis_param = django_instance_field_to_redis_value(
                 django_instance,
                 django_field,
