@@ -126,11 +126,11 @@ class RedisDateTime(RedisString):
 
 class RedisForeignKey(RedisNumber):
 
-    def __init__(self, *args, model=None, **kwargs):
-        super().__init__(*args, **kwargs)
+    def __init__(self, model=None, *args, **kwargs):
         if not issubclass(model, RedisModel):
             raise Exception(f'{model.__name__} class is not RedisModel')
         self.model = model
+        super().__init__(*args, **kwargs)
 
     def _get_id_from_instance_dict(self):
         if self.value:
@@ -174,7 +174,7 @@ class RedisForeignKey(RedisNumber):
 
 class RedisJson(RedisField):
 
-    def __init__(self, *args, json_allowed_types=(list, dict), **kwargs):
+    def __init__(self, json_allowed_types=(list, dict), *args, **kwargs):
         self.json_allowed_types = json_allowed_types
         super().__init__(*args, **kwargs)
 
@@ -229,11 +229,11 @@ class RedisList(RedisJson):
 
 class RedisManyToMany(RedisList):
 
-    def __init__(self, *args, model=None, **kwargs):
-        super().__init__(*args, **kwargs)
+    def __init__(self, model=None, *args, **kwargs):
         if not issubclass(model, RedisModel):
             raise Exception(f'{model.__name__} class is not RedisModel')
         self.model = model
+        super().__init__(*args, **kwargs)
 
     def clean(self):
         self.value = self.check_value()
@@ -438,6 +438,7 @@ class RedisRoot:
                 def get_allowed_params(django_field):
                     allowed_params = ['null', 'default', 'choices']
                     allowed_redis_params = {}
+                    print(django_field.__dict__)
                     for django_field_param_name in django_field.__dict__.keys():
                         if django_field_param_name in allowed_params:
                             value = getattr(django_field, django_field_param_name)
@@ -484,11 +485,12 @@ class RedisRoot:
                     redis_field = RedisString
 
                 if redis_field:
-                    redis_field = type(
+                    redis_field_class = type(
                         django_field.__class__.__name__,
                         (redis_field,),
-                        get_allowed_params(django_field)
+                        {}
                     )
+                    redis_field = redis_field_class(**get_allowed_params(django_field))
                 return redis_field
 
             def create_redis_model_from_django_model(django_model, redis_root):
@@ -947,7 +949,8 @@ class RedisModel:
         for field_name, field in fields.items():
             if not field_name.startswith('__'):
                 try:
-                    cleaned_value = field.clean(field)
+                    print(field_name, field, field.__class__)
+                    cleaned_value = field.clean()
                     if full:
                         field_ttl = self.get_field_ttl(field)
                         cleaned_fields[model_key + f':{field_name}'] = {
